# Django UK Geo Utils

Django app for working with OS AddressBase, ONSUD and ONSPD

---

[![Build Status](https://travis-ci.org/DemocracyClub/uk-geo-utils.svg?branch=master)](https://travis-ci.org/DemocracyClub/uk-geo-utils)
[![Coverage Status](https://coveralls.io/repos/github/DemocracyClub/uk-geo-utils/badge.svg?branch=master)](https://coveralls.io/github/DemocracyClub/uk-geo-utils?branch=master)


* [Documentation](https://democracyclub.github.io/uk-geo-utils/)
* [Support](https://github.com/DemocracyClub/uk-geo-utils/issues)
* [Code of Conduct](https://democracyclub.org.uk/code-of-conduct/)
